@@ -20,18 +20,18 @@ def build_config() -> dict[str, str]:
 
         # Package versions
         contourpy_version="1.2.1",
-        meson_version="1.4.0",
+        meson_version="1.4.1",
         mesonpy_version="0.16.0",
         pybind11_version="2.12.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-pj7rzzdx/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-rfn608zo/lib/contourpy/util",
         source_dir=r"/build/python-contourpy/src/contourpy-1.2.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-pj7rzzdx/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-rfn608zo/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="12.1.0",
+        compiler_version="14.1.1",
         linker_id="ld.bfd",
         compile_command="c++",
 
